@@ -2,6 +2,7 @@ import threading
 import typing as tp
 
 from ..structures.proxy import Proxy
+
 T = tp.TypeVar('T')
 
 
@@ -17,10 +18,10 @@ class LockedStructure(Proxy, tp.Generic[T]):
     >>> locked_dict = LockedStructure(dict)
     >>> with locked_dict:
     >>>     locked_dict[5] = 2
-    
+
     Also, please note that operations such as addition will strip this object of being a locked
     structure, ie. they will return object that participated in locked structure plus some other.
-    
+
     Note that in-place operations return the locked structure.
     """
     __slots__ = ('__lock',)
@@ -29,16 +30,16 @@ class LockedStructure(Proxy, tp.Generic[T]):
         super().__init__(obj_to_wrap)
         self.__lock = lock or threading.Lock()
 
-    def __setattr__(self, key, value):
+    def __setattr__(self, key, value) -> None:
         if key == '_LockedStructure__lock':
             object.__setattr__(self, key, value)
         else:
             super().__setattr__(key, value)
 
-    def __enter__(self):
+    def __enter__(self) -> 'LockedStructure':
         self.__lock.acquire()
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(self, exc_type, exc_val, exc_tb) -> bool:
         self.__lock.release()
         return False
