@@ -59,6 +59,29 @@ class Condition(PythonCondition):
             super().notify(n=n)
 
 
+class SingleStartThread(threading.Thread):
+    """
+    A thread that keeps track of whether it's .start() method was called, and does nothing
+    if it's called second or so time.
+    """
+
+    def __init__(self, *args, **kwargs):
+        self.__started = False
+        super().__init__(*args, **kwargs)
+
+    def start(self) -> 'SingleStartThread':
+        """
+        No-op when called second or so time. The first time it starts the thread.
+
+        :return: self
+        """
+        if self.__started:
+            return
+        self.__started = True
+        super().start()
+        return self
+
+
 class TerminableThread(threading.Thread):
     """
     Class that will execute something in a loop unless terminated. Use like:
@@ -66,8 +89,7 @@ class TerminableThread(threading.Thread):
     >>> class MeGrimlock(TerminableThread):
     >>>     def loop(self):
     >>>         ... do your operations ..
-    >>> a = MeGrimlock()
-    >>> a.start()
+    >>> a = MeGrimlock().start()
     >>> a.terminate().join()
 
     Flag whether to terminate is stored in **self._terminating**.
@@ -100,6 +122,14 @@ class TerminableThread(threading.Thread):
         between calls.
         """
 
+    def start(self) -> 'TerminableThread':
+        """
+        Start the execution of this thread
+        :return: this thread
+        """
+        super().start()
+        return self
+
     def run(self) -> None:
         """
         Calls self.loop() indefinitely, until terminating condition is met
@@ -135,7 +165,7 @@ class TerminableThread(threading.Thread):
         """
         t = 0
         while t < interval and not self._terminating:
-            remaining_to_sleep = min(interval-t, wake_up_each)
+            remaining_to_sleep = min(interval - t, wake_up_each)
             time.sleep(remaining_to_sleep)
             t += remaining_to_sleep
         return self._terminating
