@@ -7,7 +7,7 @@ from .exceptions import ProcessFailed
 __all__ = ['call_and_return_stdout']
 
 
-def read_nowait(process: subprocess.Popen, output_list: tp.List[str]) -> None:
+def _read_nowait(process: subprocess.Popen, output_list: tp.List[str]) -> None:
     """
     To be launched as a daemon thread. This reads stdout and appends it's entries to a list.
     This should finish as soon as the process exits or closes it's stdout.
@@ -58,7 +58,7 @@ def call_and_return_stdout(args: tp.Union[str, tp.List[str]],
 
     proc = subprocess.Popen(args, **kwargs)
     reader_thread = threading.Thread(name='stdout reader',
-                                     target=read_nowait,
+                                     target=_read_nowait,
                                      args=(proc, stdout_list),
                                      daemon=True)
     reader_thread.start()
